;; Generated package description from orderless.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "orderless" "1.6.0.20260502.95406" "Completion style for matching regexps in any order" '((emacs "27.1") (compat "31")) :commit "34785f1eb40a241a7949ebe258d563bfa061bc50" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '(("Omar Antolín Camarena" . "omar@matem.unam.mx") ("Daniel Mendler" . "mail@daniel-mendler.de")) :keywords '("matching" "completion") :url "https://github.com/oantolin/orderless")
